use thiserror::Error;

pub mod flow;
pub mod sled;

#[derive(Clone, Debug, Error, PartialEq)]
pub enum FatalError {
    #[error("Database corruption detected")]
    DatabaseCorruption,
}

impl ::result_extended::FatalError for FatalError {}

#[derive(Clone, Debug, Error, PartialEq)]
pub enum MathError {
    #[error("divide by zero is not defined")]
    DivideByZero,

    #[error("result exceeds maxint")]
    ExceedsMaxint,

    #[error("result exceeds minint")]
    ExceedsMinint,
}

#[derive(Clone, Debug, Error, PartialEq)]
pub enum DatabaseError {
    #[error("value not found")]
    NotFound,
}

#[derive(Clone, Debug, Error, PartialEq)]
pub enum OperationError {
    #[error("database error occurred: {0}")]
    DatabaseError(DatabaseError),

    #[error("math error occurred: {0}")]
    MathError(MathError),
}

impl From<DatabaseError> for OperationError {
    fn from(err: DatabaseError) -> Self {
        Self::DatabaseError(err)
    }
}

impl From<MathError> for OperationError {
    fn from(err: MathError) -> Self {
        Self::MathError(err)
    }
}
