//! Error handling practice.
//!
//! The purpose of this crate is to demonstrate error handling in a couple of different scenarios
//! so that I have clear templates to refer when doing development, instead of hand-waving or
//! putting error handling off into the unspecified future.
//!
//! I am going to demonstrate error handling in the style of [Error Handling in a
//! Correctness-Critical Rust Project | sled-rs.github.io](https://sled.rs/errors.html) and in my
//! reformulation of it using Flow.
//!
//! I will also test out additional libraries in the same scenarios:
//!
//! - anyhow
//!
//! A database exists with some numbers. Mathmatical calculations will be performed on those
//! numbers. Some calculations are invalid and should fail. In some cases, those should be reported
//! to the user, and in other cases those can be recovered. Sometimes a calculation needs to be
//! performed on a value that doesn't exist, which is also a failure. However, sometimes, the
//! database will detect corruption, wich is fatal and should terminate the "app".
//!
//! In these scenarios, the "app" is a top-level function which runs the scenario. This particular
//! app should never crash, just show where crashes would happen.

fn main() {
    println!("Hello, world!");
}
